@@ -1,6 +1,6 @@
 from django.contrib import admin
 from edc_adverse_event.modeladmin_mixins import AeFollowupModelAdminMixin
-from edc_model_admin import SimpleHistoryAdmin
+from edc_model_admin.history import SimpleHistoryAdmin
 
 from ..admin_site import meta_ae_admin
 from ..forms import AeFollowupForm
