@@ -12,7 +12,6 @@ from meta_ae.models.death_report import DeathReport
 aeinitial = Recipe(
     AeInitial,
     action_identifier=None,
-    tracking_identifier=None,
     ae_description="A description of this event",
     ae_grade=GRADE4,
     ae_study_relation_possibility=YES,
@@ -27,17 +26,14 @@ aeinitial = Recipe(
     ae_cause_other=None,
 )
 
-aetmg = Recipe(AeTmg, action_identifier=None, tracking_identifier=None)
+aetmg = Recipe(AeTmg, action_identifier=None)
 
-aesusar = Recipe(AeSusar, action_identifier=None, tracking_identifier=None)
+aesusar = Recipe(AeSusar, action_identifier=None)
 
-aefollowup = Recipe(
-    AeFollowup, relevant_history=NO, action_identifier=None, tracking_identifier=None
-)
+aefollowup = Recipe(AeFollowup, relevant_history=NO, action_identifier=None)
 
 deathreport = Recipe(
     DeathReport,
     subject_identifier=None,
     action_identifier=None,
-    tracking_identifier=None,
 )
