@@ -1,7 +1,7 @@
 from django import forms
-from edc_adverse_event.forms import validate_ae_initial_outcome_date
+from edc_adverse_event.modelform_mixins import AeModelFormMixin
+from edc_adverse_event.utils import validate_ae_initial_outcome_date
 from edc_form_validators import FormValidator, FormValidatorMixin
-from edc_registration.modelform_mixins import ModelFormSubjectIdentifierMixin
 
 
 class AeReviewFormValidator(FormValidator):
@@ -10,7 +10,7 @@ class AeReviewFormValidator(FormValidator):
 
 
 class AeReviewModelFormMixin(
-    ModelFormSubjectIdentifierMixin,
+    AeModelFormMixin,
     FormValidatorMixin,
 ):
     form_validator_cls = AeReviewFormValidator
