@@ -17,7 +17,7 @@ from edc_export.auth_objects import DATA_EXPORTER_ROLE
 from edc_mnsi.auth_objects import MNSI, MNSI_SUPER, MNSI_VIEW
 from edc_pharmacy.auth_objects import (
     PHARMACIST_ROLE,
-    PRESCRIBER_ROLE,
+    PHARMACY_PRESCRIBER,
     SITE_PHARMACIST_ROLE,
 )
 from edc_qol.auth_objects import QOL, QOL_SUPER, QOL_VIEW
@@ -41,14 +41,14 @@ site_auths.update_role(
     UNBLINDING_REQUESTORS,
     MNSI,
     QOL,
-    PRESCRIBER_ROLE,
+    PHARMACY_PRESCRIBER,
     name=CLINICIAN_ROLE,
 )
 site_auths.update_role(
     MNSI_SUPER,
     QOL_SUPER,
     UNBLINDING_REQUESTORS,
-    PRESCRIBER_ROLE,
+    PHARMACY_PRESCRIBER,
     name=CLINICIAN_SUPER_ROLE,
 )
 site_auths.update_role(MNSI, QOL, name=NURSE_ROLE)
