@@ -13,8 +13,8 @@ navbar.append_item(
         name="screened_subject",
         title="Screening",
         label="Screening",
-        fa_icon="fas fa-user-plus",
-        codename="edc_navbar.nav_screening_section",
+        fa_icon="fa-solid fa-user-plus",
+        codename="edc_screening.view_screening_listboard",
         url_name="screening_listboard_url",
         no_url_namespace=no_url_namespace,
     )
@@ -25,8 +25,8 @@ navbar.append_item(
         name="consented_subject",
         title="Subjects",
         label="Subjects",
-        fa_icon="far fa-user-circle",
-        codename="edc_navbar.nav_subject_section",
+        fa_icon="fa-solid fa-user-circle",
+        codename="edc_subject_dashboard.view_subject_listboard",
         url_name="subject_listboard_url",
         no_url_namespace=no_url_namespace,
     )
