@@ -46,7 +46,7 @@ urlpatterns = [
     *paths_for_urlpatterns("edc_pdutils"),
     *paths_for_urlpatterns("edc_pharmacy"),
     *paths_for_urlpatterns("edc_protocol"),
-    *paths_for_urlpatterns("edc_protocol_violation"),
+    *paths_for_urlpatterns("edc_protocol_incident"),
     *paths_for_urlpatterns("edc_qol"),
     *paths_for_urlpatterns("edc_randomization"),
     *paths_for_urlpatterns("edc_reference"),
