@@ -1,13 +1,13 @@
 from tempfile import mkdtemp
 
-from django.test import TestCase, tag
+from django.test import TestCase
 from edc_reportable import ParserError, site_reportables
 
 
 class TestReportables(TestCase):
     def test(self):
         try:
-            from meta_labs import reportables
+            from meta_labs import reportables  # noqa
         except ParserError:
             self.fail("ParserError unexpectedly raised.")
         self.assertIsNotNone(site_reportables.get("meta"))
