@@ -1,9 +1,9 @@
 from .end_of_study_admin import EndOfStudyAdmin
 from .loss_to_followup_admin import LossToFollowupAdmin
+from .off_study_medication_admin import OffStudyMedicationAdmin
 from .offschedule_admin import OffScheduleAdmin
 from .offschedule_postnatal_admin import OffSchedulePostnatalAdmin
 from .offschedule_pregnancy_admin import OffSchedulePregnancyAdmin
-from .offstudy_medication_admin import OffstudyMedicationAdmin
 from .onschedule_admin import OnScheduleAdmin
 from .pregnancy_notification_admin import PregnancyNotificationAdmin
 from .protocol_incident_admin import ProtocolDeviationViolationAdmin
