@@ -2,8 +2,8 @@ from typing import Tuple
 
 from django.contrib import admin
 from edc_data_manager.modeladmin_mixins import DataManagerModelAdminMixin
-from edc_model_admin import SimpleHistoryAdmin
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
+from edc_model_admin.history import SimpleHistoryAdmin
 
 from ..admin_site import meta_prn_admin
 from ..models import OnSchedule
