@@ -1,7 +1,7 @@
 from django.contrib import admin
 from edc_action_item import ActionItemModelAdminMixin
-from edc_model_admin import SimpleHistoryAdmin
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
+from edc_model_admin.history import SimpleHistoryAdmin
 from edc_transfer.modeladmin_mixins import SubjectTransferModelAdminMixin
 
 from ..admin_site import meta_prn_admin
