@@ -15,10 +15,12 @@ from edc_form_validators import INVALID_ERROR, FormValidator
 from edc_ltfu.constants import LTFU
 from edc_ltfu.modelform_mixins import RequiresLtfuFormValidatorMixin
 from edc_offstudy.constants import COMPLETED_FOLLOWUP
-from edc_offstudy.utils import OffstudyError, off_all_schedules_or_raise
+from edc_offstudy.utils import OffstudyError
+from edc_prn.modelform_mixins import PrnFormValidatorMixin
 from edc_transfer.constants import TRANSFERRED
 from edc_utils import formatted_date
 from edc_visit_schedule.constants import MONTH36
+from edc_visit_schedule.utils import off_all_schedules_or_raise
 
 from ..constants import (
     CLINICAL_WITHDRAWAL,
@@ -30,6 +32,7 @@ from ..constants import (
 class EndOfStudyFormValidator(
     RequiresDeathReportFormValidatorMixin,
     RequiresLtfuFormValidatorMixin,
+    PrnFormValidatorMixin,
     FormValidator,
 ):
     death_report_model = "meta_ae.deathreport"
@@ -234,7 +237,6 @@ class EndOfStudyFormValidator(
         try:
             off_all_schedules_or_raise(
                 subject_identifier=self.cleaned_data.get("subject_identifier"),
-                offstudy_datetime=self.cleaned_data.get("offstudy_datetime"),
             )
         except OffstudyError as e:
             self.raise_validation_error(str(e), INVALID_ERROR)
