@@ -1,8 +1,8 @@
 from .end_of_study_form import EndOfStudyForm
 from .loss_to_followup_form import LossToFollowupForm
+from .off_study_medication_form import OffStudyMedicationForm
 from .offschedule_form import OffScheduleForm
 from .offschedule_pregnancy_form import OffSchedulePregnancyForm
-from .offstudy_medication_form import OffstudyMedicationForm
 from .pregnancy_notification_form import PregnancyNotificationForm
 from .protocol_incident_form import ProtocolIncidentForm
 from .subject_transfer_form import SubjectTransferForm
