@@ -1,7 +1,7 @@
 from .end_of_study import EndOfStudy
 from .loss_to_followup import LossToFollowup
+from .off_study_medication import OffStudyMedication
 from .offschedule import OffSchedule, OffSchedulePostnatal, OffSchedulePregnancy
-from .offstudy_medication import OffstudyMedication
 from .onschedule import OnSchedule, OnSchedulePostnatal, OnSchedulePregnancy
 from .pregnancy_notification import PregnancyNotification
 from .protocol_incident import ProtocolIncident
