@@ -1,40 +1,42 @@
 from edc_action_item.models import ActionModelMixin
 from edc_model.models import BaseUuidModel
+from edc_sites.models import SiteModelMixin
 from edc_visit_schedule.model_mixins import OffScheduleModelMixin
 
-from meta_prn.constants import (
+from ..constants import (
     OFFSCHEDULE_ACTION,
     OFFSCHEDULE_POSTNATAL_ACTION,
     OFFSCHEDULE_PREGNANCY_ACTION,
 )
 
 
-class OffSchedule(ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
+class OffSchedule(SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
 
     action_name = OFFSCHEDULE_ACTION
+    offschedule_compare_dates_as_datetimes = False
 
-    tracking_identifier_prefix = "OX"
-
-    class Meta(OffScheduleModelMixin.Meta):
+    class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Off-schedule"
         verbose_name_plural = "Off-schedule"
 
 
-class OffSchedulePregnancy(ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
+class OffSchedulePregnancy(
+    SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel
+):
+
     action_name = OFFSCHEDULE_PREGNANCY_ACTION
 
-    tracking_identifier_prefix = "OP"
-
-    class Meta(OffScheduleModelMixin.Meta):
+    class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Off-schedule: Pregnancy"
         verbose_name_plural = "Off-schedule: Pregnancy"
 
 
-class OffSchedulePostnatal(ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
+class OffSchedulePostnatal(
+    SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel
+):
+
     action_name = OFFSCHEDULE_POSTNATAL_ACTION
 
-    tracking_identifier_prefix = "ON"
-
-    class Meta(OffScheduleModelMixin.Meta):
+    class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Off-schedule: post-natal"
         verbose_name_plural = "Off-schedule: post-natal"
