@@ -2,18 +2,18 @@ from django.db import models
 from edc_action_item.models import ActionItem, ActionModelMixin
 from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model.models import BaseUuidModel
-from edc_protocol_violation.constants import PROTOCOL_INCIDENT_ACTION
-from edc_protocol_violation.model_mixins import ProtocolIncidentModelMixin
+from edc_protocol_incident.constants import PROTOCOL_INCIDENT_ACTION
+from edc_protocol_incident.model_mixins import ProtocolIncidentModelMixin
 from edc_sites.models import SiteModelMixin
 
 from ..choices import ACTION_REQUIRED
 
 
 class ProtocolIncident(
-    ProtocolIncidentModelMixin,
-    NonUniqueSubjectIdentifierFieldMixin,
     SiteModelMixin,
     ActionModelMixin,
+    ProtocolIncidentModelMixin,
+    NonUniqueSubjectIdentifierFieldMixin,
     BaseUuidModel,
 ):
 
