@@ -2,12 +2,15 @@ from django import forms
 from edc_consent.form_validators import ConsentFormValidatorMixin
 from edc_constants.constants import MALE, YES
 from edc_form_validators import FormValidator
+from edc_prn.modelform_mixins import PrnFormValidatorMixin
 
 
-class ScreeningPartOneFormValidator(ConsentFormValidatorMixin, FormValidator):
+class ScreeningPartOneFormValidator(
+    ConsentFormValidatorMixin, PrnFormValidatorMixin, FormValidator
+):
     def clean(self):
 
-        self.get_consent_for_period_or_raise(self.cleaned_data.get("report_datetime"))
+        self.get_consent_for_period_or_raise()
 
         if (
             not self.cleaned_data.get("screening_consent")
