@@ -1,16 +1,26 @@
-from zoneinfo import ZoneInfo
+from __future__ import annotations
+
+from datetime import datetime
 
 from django import forms
 from edc_constants.constants import NO, YES
 from edc_form_validators import INVALID_ERROR, FormValidator
-from edc_utils import get_utcnow
+from edc_prn.modelform_mixins import PrnFormValidatorMixin
+from edc_utils import formatted_datetime, get_utcnow, to_utc
+from edc_utils.date import to_local
+from edc_utils.round_up import round_half_away_from_zero
 
 from ..eligibility import EligibilityPartTwo
 
 
-class ScreeningPartTwoFormValidator(FormValidator):
+class ScreeningPartTwoFormValidator(PrnFormValidatorMixin, FormValidator):
+
+    report_datetime_field_attr = "part_two_report_datetime"
+
     def clean(self):
 
+        self.validate_report_datetimes()
+
         if (
             self.cleaned_data.get("agree_to_p3") == YES
             and self.cleaned_data.get("advised_to_fast") == NO
@@ -27,21 +37,19 @@ class ScreeningPartTwoFormValidator(FormValidator):
 
         self.required_if(YES, field="advised_to_fast", field_required="appt_datetime")
 
-        if self.cleaned_data.get("appt_datetime"):
-            self.raise_if_not_future_appt_datetime()
+        self.raise_if_not_future_appt_datetime()
 
-        if not self.instance.part_three_report_datetime:
+        if not self.part_three_report_datetime:
             self.applicable_if_true(
                 self.cleaned_data.get("appt_datetime")
-                and self.cleaned_data.get("appt_datetime").astimezone(ZoneInfo("UTC"))
-                <= get_utcnow(),
+                and to_utc(self.cleaned_data.get("appt_datetime")) <= get_utcnow(),
                 field_applicable="p3_ltfu",
                 applicable_msg="Appointment date has past",
                 not_applicable_msg="This field is not applicable. See appointment date above",
             )
         else:
             self.not_applicable_if_true(
-                self.instance.part_three_report_datetime,
+                self.part_three_report_datetime is not None,
                 field_applicable="p3_ltfu",
                 not_applicable_msg=(
                     "The second stage of screening (P3) has already been started."
@@ -50,20 +58,59 @@ class ScreeningPartTwoFormValidator(FormValidator):
 
         self.required_if(YES, field="p3_ltfu", field_required="p3_ltfu_date")
 
+    @property
+    def part_one_report_datetime(self) -> datetime:
+        return self.instance.report_datetime
+
+    @property
+    def part_three_report_datetime(self) -> datetime | None:
+        return self.instance.part_three_report_datetime
+
     @property
     def eligible_part_two(self) -> bool:
         """Returns False if any of the required fields is YES."""
         eligibility = EligibilityPartTwo(cleaned_data=self.cleaned_data)
         return eligibility.is_eligible
 
+    def validate_report_datetimes(self):
+        if (
+            self.report_datetime
+            and to_utc(self.report_datetime) < self.part_one_report_datetime
+        ):
+            dte = formatted_datetime(to_local(self.part_one_report_datetime))
+            self.raise_validation_error(
+                {
+                    self.report_datetime_field_attr: (
+                        "Cannot be before `Part One` report datetime. "
+                        f"Expected date after {dte}."
+                    )
+                },
+                INVALID_ERROR,
+            )
+
+        if (
+            self.report_datetime
+            and self.part_three_report_datetime
+            and to_utc(self.report_datetime) > self.part_three_report_datetime
+        ):
+            dte = formatted_datetime(to_local(self.part_three_report_datetime))
+            self.raise_validation_error(
+                {
+                    self.report_datetime_field_attr: (
+                        "Cannot be after `Part Three` report datetime. "
+                        f"Expected date before {dte}."
+                    )
+                },
+                INVALID_ERROR,
+            )
+
     def raise_if_not_future_appt_datetime(self):
         """Raises if appt_datetime is not future relative to
         part_two_report_datetime.
         """
         appt_datetime = self.cleaned_data.get("appt_datetime")
-        report_datetime = self.cleaned_data.get("part_two_report_datetime")
-        if appt_datetime and report_datetime:
-            tdelta = appt_datetime - report_datetime
+        if appt_datetime and self.report_datetime:
+            tdelta = appt_datetime - to_local(self.report_datetime)
 
             hours = tdelta.seconds / 3600
 
@@ -73,7 +120,7 @@ class ScreeningPartTwoFormValidator(FormValidator):
                         "appt_datetime": (
                             f"Invalid date. Must be at least 10hrs "
                             f"from report date/time. Got {tdelta.days} "
-                            f"days {round(hours,1)} hrs."
+                            f"days {round_half_away_from_zero(hours,1)} hrs."
                         )
                     }
                 )
