@@ -1,4 +1,5 @@
 from django.contrib import admin
+from edc_action_item import action_fieldset_tuple
 from edc_lab_panel.panels import hba1c_panel
 from edc_lab_results.admin import BloodResultsModelAdminMixin
 from edc_lab_results.fieldsets import BloodResultFieldset
@@ -14,4 +15,9 @@ from ..modeladmin import CrfModelAdmin
 @admin.register(BloodResultsHba1c, site=meta_subject_admin)
 class BloodResultsHba1cAdmin(BloodResultsModelAdminMixin, CrfModelAdmin):
     form = BloodResultsHba1cForm
-    fieldsets = BloodResultFieldset(hba1c_panel).fieldsets
+    fieldsets = BloodResultFieldset(
+        hba1c_panel,
+        extra_fieldsets=[
+            (-1, action_fieldset_tuple),
+        ],
+    ).fieldsets
