@@ -1,12 +1,12 @@
 from django import forms
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import InlineCrfModelFormMixin
-from edc_form_validators.form_validator import FormValidator
 
 from ..constants import LIVE_AT_TERM, LIVE_PRETERM
 from ..models import BirthOutcomes
 
 
-class BirthOutcomesFormValidator(FormValidator):
+class BirthOutcomesFormValidator(CrfFormValidator):
     def clean(self):
         self.required_if(
             LIVE_AT_TERM,
