@@ -1,11 +1,11 @@
 from django import forms
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_form_validators import FormValidator
 
 from ..models import FollowupVitals
 
 
-class FollowupVitalsFormValidator(FormValidator):
+class FollowupVitalsFormValidator(CrfFormValidator):
     pass
 
 
