@@ -1,13 +1,13 @@
 from django import forms
 from edc_action_item.forms import ActionItemCrfFormMixin
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_form_validators.form_validator import FormValidator
 from edc_glucose.form_validators import FbgOgttFormValidatorMixin
 
 from ..models import Glucose
 
 
-class GlucoseFormValidator(FbgOgttFormValidatorMixin, FormValidator):
+class GlucoseFormValidator(FbgOgttFormValidatorMixin, CrfFormValidator):
     def clean(self):
         self.validate_glucose_testing_matrix()
 
