@@ -1,12 +1,12 @@
 from django import forms
 from edc_constants.constants import NO, YES
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_form_validators import FormValidator
 
 from ..models import MalariaTest
 
 
-class MalariaTestFormValidator(FormValidator):
+class MalariaTestFormValidator(CrfFormValidator):
     def clean(self):
 
         self.applicable_if(YES, field="performed", field_applicable="diagnostic_type")
