@@ -1,14 +1,16 @@
 from django import forms
 from edc_adherence.form_validator_mixin import MedicationAdherenceFormValidatorMixin
 from edc_adherence.model_form_mixin import MedicationAdherenceFormMixin
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_form_validators.form_validator import FormValidator
 from edc_model.widgets import SliderWidget
 
 from ..models import MedicationAdherence
 
 
-class MedicationAdherenceFormValidator(MedicationAdherenceFormValidatorMixin, FormValidator):
+class MedicationAdherenceFormValidator(
+    MedicationAdherenceFormValidatorMixin, CrfFormValidator
+):
     pass
 
 
