@@ -1,12 +1,12 @@
 from django import forms
 from edc_constants.constants import YES
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_form_validators import FormValidator
 
 from ..models import PhysicalExam
 
 
-class PhysicalExamFormValidator(FormValidator):
+class PhysicalExamFormValidator(CrfFormValidator):
     def clean(self):
 
         self.required_if(
