@@ -28,21 +28,6 @@ class HealthEconomicsRuleGroup(CrfRuleGroup):
         source_model = "meta_subject.subjectvisit"
 
 
-@register()
-class UrinePregnancyRuleGroup(CrfRuleGroup):
-
-    bhcg = CrfRule(
-        predicate=pc.urine_pregnancy_required,
-        consequence=REQUIRED,
-        alternative=NOT_REQUIRED,
-        target_models=["urinepregnancy"],
-    )
-
-    class Meta:
-        app_label = "meta_subject"
-        source_model = "meta_subject.subjectvisit"
-
-
 @register()
 class HbA1cCrfRuleGroup(CrfRuleGroup):
 
