@@ -1,4 +1,3 @@
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
 from edc_lab.model_mixins import CrfWithRequisitionModelMixin
 from edc_lab_panel.panels import fbc_panel
 from edc_lab_results import BLOOD_RESULTS_FBC_ACTION
@@ -13,7 +12,9 @@ from edc_lab_results.model_mixins import (
     RbcModelMixin,
     WbcModelMixin,
 )
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
+
+from ...model_mixins import CrfWithActionModelMixin
 
 
 class BloodResultsFbc(
@@ -28,13 +29,13 @@ class BloodResultsFbc(
     MchcModelMixin,
     McvModelMixin,
     BloodResultsModelMixin,
-    edc_models.BaseUuidModel,
+    BaseUuidModel,
 ):
     action_name = BLOOD_RESULTS_FBC_ACTION
     tracking_identifier_prefix = "FB"
 
     lab_panel = fbc_panel
 
-    class Meta(CrfWithActionModelMixin.Meta, edc_models.BaseUuidModel.Meta):
+    class Meta(CrfWithActionModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Blood Result: FBC"
         verbose_name_plural = "Blood Results: FBC"
