@@ -1,4 +1,3 @@
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
 from edc_lab.model_mixins import CrfWithRequisitionModelMixin
 from edc_lab_panel.panels import lft_panel
 from edc_lab_results import BLOOD_RESULTS_LFT_ACTION
@@ -11,7 +10,9 @@ from edc_lab_results.model_mixins import (
     BloodResultsModelMixin,
     GgtModelMixin,
 )
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
+
+from ...model_mixins import CrfWithActionModelMixin
 
 
 class BloodResultsLft(
@@ -24,12 +25,12 @@ class BloodResultsLft(
     GgtModelMixin,
     CrfWithRequisitionModelMixin,
     BloodResultsModelMixin,
-    edc_models.BaseUuidModel,
+    BaseUuidModel,
 ):
     action_name = BLOOD_RESULTS_LFT_ACTION
     tracking_identifier_prefix = "LF"
     lab_panel = lft_panel
 
-    class Meta(CrfWithActionModelMixin.Meta, edc_models.BaseUuidModel.Meta):
+    class Meta(CrfWithActionModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Blood Result: LFT"
         verbose_name_plural = "Blood Results: LFT"
