@@ -1,4 +1,3 @@
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
 from edc_lab.model_mixins import CrfWithRequisitionModelMixin
 from edc_lab_panel.panels import lipids_panel
 from edc_lab_results import BLOOD_RESULTS_LIPID_ACTION
@@ -9,7 +8,9 @@ from edc_lab_results.model_mixins import (
     LdlModelMixin,
     TrigModelMixin,
 )
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
+
+from ...model_mixins import CrfWithActionModelMixin
 
 
 class BloodResultsLipid(
@@ -20,12 +21,12 @@ class BloodResultsLipid(
     CholModelMixin,
     CrfWithRequisitionModelMixin,
     BloodResultsModelMixin,
-    edc_models.BaseUuidModel,
+    BaseUuidModel,
 ):
     action_name = BLOOD_RESULTS_LIPID_ACTION
     tracking_identifier_prefix = "LP"
     lab_panel = lipids_panel
 
-    class Meta(CrfWithActionModelMixin.Meta, edc_models.BaseUuidModel.Meta):
+    class Meta(CrfWithActionModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Blood Result: Lipids"
         verbose_name_plural = "Blood Results: Lipids"
