@@ -1,15 +1,15 @@
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
 
 from ..model_mixins import CrfModelMixin
 
 
-class ConcomitantMedication(CrfModelMixin, edc_models.BaseUuidModel):
+class ConcomitantMedication(CrfModelMixin, BaseUuidModel):
 
     # prescription
     # days
     # dosage
     # instructions
 
-    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
+    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Concomitant Medication"
         verbose_name_plural = "Concomitant Medication"
