@@ -7,9 +7,7 @@ from django.db import models
 from django_crypto_fields.fields import EncryptedTextField
 from edc_constants.choices import YES_NO, YES_NO_NA
 from edc_constants.constants import NOT_APPLICABLE, PATIENT, YES
-from edc_crf.crf_status_model_mixin import CrfStatusModelMixin
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
 from edc_model.validators import datetime_not_future
 from edc_model_fields.fields import OtherCharField
 from edc_protocol.validators import datetime_not_before_study_start
@@ -22,6 +20,7 @@ from ..choices import (
     MATERNAL_OUTCOMES,
 )
 from ..constants import DELIVERY_ACTION
+from ..model_mixins import CrfWithActionModelMixin
 
 
 class DeliveryError(Exception):
@@ -29,9 +28,8 @@ class DeliveryError(Exception):
 
 
 class Delivery(
-    CrfStatusModelMixin,
     CrfWithActionModelMixin,
-    edc_models.BaseUuidModel,
+    BaseUuidModel,
 ):
     """A user model to capture delivery and birth outcomes.
 
@@ -161,7 +159,7 @@ class Delivery(
             )
         super().save(*args, **kwargs)
 
-    class Meta(edc_models.BaseUuidModel.Meta):
+    class Meta(CrfWithActionModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Delivery"
         verbose_name_plural = "Delivery"
         unique_together = ["subject_visit", "delivery_datetime"]
