@@ -1,14 +1,12 @@
 from django.db import models
 from edc_constants.choices import MARITAL_STATUS
 from edc_he.model_mixins import HealthEconomicsEducationModelMixin
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
 
 from ..model_mixins import CrfModelMixin
 
 
-class HealthEconomicsSimple(
-    HealthEconomicsEducationModelMixin, CrfModelMixin, edc_models.BaseUuidModel
-):
+class HealthEconomicsSimple(HealthEconomicsEducationModelMixin, CrfModelMixin, BaseUuidModel):
 
     occupation = models.CharField(
         verbose_name="What is your occupation/profession?", max_length=50
@@ -20,6 +18,6 @@ class HealthEconomicsSimple(
         choices=MARITAL_STATUS,
     )
 
-    class Meta:
+    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Health Economics (M3)"
         verbose_name_plural = "Health Economics (M3)"
