@@ -1,13 +1,13 @@
 from django.db import models
 from edc_constants.choices import PRESENT_ABSENT_NA, YES_NO
 from edc_constants.constants import NOT_APPLICABLE
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
 
 from ..choices import MALARIA_TEST_CHOICES
 from ..model_mixins import CrfModelMixin
 
 
-class MalariaTest(CrfModelMixin, edc_models.BaseUuidModel):
+class MalariaTest(CrfModelMixin, BaseUuidModel):
 
     performed = models.CharField(
         verbose_name="Was the malaria test performed?",
@@ -33,5 +33,5 @@ class MalariaTest(CrfModelMixin, edc_models.BaseUuidModel):
         default=NOT_APPLICABLE,
     )
 
-    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
+    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Malaria Test"
