@@ -1,13 +1,13 @@
 from django.db import models
 from edc_constants.choices import YES_NO
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
 from edc_model.validators import date_not_future
 from edc_protocol.validators import date_not_before_study_start
 
 from ..model_mixins import CrfModelMixin
 
 
-class OffStudyMedication(CrfModelMixin, edc_models.BaseUuidModel):
+class OffStudyMedication(CrfModelMixin, BaseUuidModel):
 
     last_dose_date = models.DateField(
         verbose_name="Date of last known dose",
@@ -20,8 +20,5 @@ class OffStudyMedication(CrfModelMixin, edc_models.BaseUuidModel):
         choices=YES_NO,
     )
 
-    class Meta(
-        CrfModelMixin.Meta,
-        edc_models.BaseUuidModel.Meta,
-    ):
+    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
         pass
