@@ -1,7 +1,6 @@
 from django.db import models
-from edc_crf.crf_inline_model_mixin import CrfInlineModelMixin
-from edc_model import models as edc_models
-from edc_model.models import HistoricalRecords
+from edc_crf.model_mixins import CrfInlineModelMixin
+from edc_model.models import BaseUuidModel, HistoricalRecords
 from edc_model.validators import date_is_not_now, date_not_future
 from edc_model_fields.fields import OtherCharField
 from edc_sites.models import CurrentSiteManager
@@ -23,7 +22,7 @@ class InlineModelManager(models.Manager):
         return self.get(other_arv_regimens=other_arv_regimens, arv_regimen=arv_regimen)
 
 
-class OtherArvRegimensDetail(CrfInlineModelMixin, edc_models.BaseUuidModel):
+class OtherArvRegimensDetail(CrfInlineModelMixin, BaseUuidModel):
 
     other_arv_regimens = models.ForeignKey(
         OtherArvRegimens,
@@ -57,7 +56,7 @@ class OtherArvRegimensDetail(CrfInlineModelMixin, edc_models.BaseUuidModel):
     def natural_key(self) -> tuple:
         return self.other_arv_regimens, self.arv_regimen
 
-    class Meta(edc_models.BaseUuidModel.Meta):
+    class Meta(CrfInlineModelMixin.Meta, BaseUuidModel.Meta):
         crf_inline_parent = "other_arv_regimens"
         verbose_name = "Other ARV Regimens Detail"
         verbose_name_plural = "Other ARV Regimens Detail"
