@@ -1,17 +1,17 @@
 from django.db import models
-from edc_crf.crf_model_mixin import CrfModelMixin
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
-from edc_model import models as edc_models
+from edc_model.models import BaseUuidModel
 from edc_visit_tracking.model_mixins import SubjectVisitMissedModelMixin
 
 from meta_lists.models import SubjectVisitMissedReasons
-from meta_subject.constants import MISSED_VISIT_ACTION
+
+from ..constants import MISSED_VISIT_ACTION
+from ..model_mixins import CrfWithActionModelMixin
 
 
 class SubjectVisitMissed(
     SubjectVisitMissedModelMixin,
     CrfWithActionModelMixin,
-    edc_models.BaseUuidModel,
+    BaseUuidModel,
 ):
 
     action_name = MISSED_VISIT_ACTION
@@ -20,6 +20,6 @@ class SubjectVisitMissed(
         SubjectVisitMissedReasons, blank=True, related_name="meta_missed_reasons"
     )
 
-    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
+    class Meta(CrfWithActionModelMixin.Meta, BaseUuidModel.Meta):
         verbose_name = "Missed Visit Report"
         verbose_name_plural = "Missed Visit Report"
